@@ -15,10 +15,12 @@ VENUE_PATH in sys.path or sys.path.insert(1, VENUE_PATH)
 ACTS_DIR in sys.path or sys.path.insert(1, ACTS_DIR)
 syspath = sys.path
 exec('from %s.settings import *' % VENUE_NAME)
-
 from theme_settings import *
 
-from db_settings import DATABASES
+from db_settings import DATABASES as ACT_DATABASES
+for db in ACT_DATABASES.items():
+    DATABASES[db[0]] = db[1]
+
 DATABASES['default']['NAME'] = 'backstage_%s_%s' % (VENUE_NAME, ACT_NAME)
 
 from act_settings import *
@@ -30,9 +32,9 @@ TEMPLATE_DIRS.append('%s/instruments/local/templates/ads' % VENUE_ROOT)
 
 ROOT_URLCONF = '%s.urls' % (ACT_NAME)
 
+ACT_NAME in INSTALLED_APPS or INSTALLED_APPS.insert(0,ACT_NAME)
 for act in ACT_APPS:
     act in INSTALLED_APPS or INSTALLED_APPS.append(act)
-INSTALLED_APPS.insert(0, ACT_NAME)
 
 try:
     from act_settings import WWW_DEFAULT_HOSTS
